import logging


class LogUtil:
    @staticmethod
    def debug(message):
        logging.debug(message)

    @staticmethod
    def info(message):
        logging.info(message)

    @staticmethod
    def warn(message):
        logging.warn(message)

    @staticmethod
    def error(message):
        logging.error(message)



class MathUtil:
    @staticmethod
    def add(x, y):
        return x + y

    @staticmethod
    def subtract(x, y):
        return x - y

    @staticmethod
    def multiply(x, y):
        return x * y

    @staticmethod
    def divide(x, y):
        if y == 0:
            raise ValueError("Can't divide by zero!")
        return x / y



from setuptools import setup, find_packages

packages = find_packages()
print(packages)

setup(
    name="fishyer_helper",
    version="0.0.3",
    packages=packages,
    description="My Python Util Package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="fishyer",
    author_email="yutianran66@gamil.com",
    url="https://github.com/fishyer/python-util",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
